@@ -61,8 +61,7 @@ def cli(ctx, verbose: bool):
 @cli.command(default_command=True)
 @click.argument("input_file", required=True)
 @click.argument("output_file", required=True)
-@click.option("--strict-map-keys", is_flag=True, default=False, help="Enable strict map keys in msgpack files (sets strict_map_key=True)")
-def convert(input_file, output_file, strict_map_keys):
+def convert(input_file, output_file):
     """Convert between atomic structure file formats using ASE
 
     Supports all formats that ASE can read/write, with special handling for .atm and .atraj files.
@@ -71,14 +70,13 @@ def convert(input_file, output_file, strict_map_keys):
       tess input.xyz output.atm
       tess input.traj output.atraj
       
-    Options:
-      --strict-map-keys  Enable strict map keys in msgpack files (default: False)
     """ 
     try:
         import os.path
         from ase.io import read, write
         from ase.io.formats import UnknownFileTypeError
-        from atomict.io.msgpack import save_msgpack, save_msgpack_trajectory, load_msgpack, load_msgpack_trajectory
+        from atomict.io.formats.atraj import read_atraj, write_atraj
+        from atomict.io.formats.tess import read_tess, write_tess
     except ImportError:
         console.print("[red]Error: ASE (Atomic Simulation Environment) is required for file conversion.[/red]")
         console.print("[yellow]Install it with: pip install ase[/yellow]")
@@ -103,30 +101,34 @@ def convert(input_file, output_file, strict_map_keys):
             console.print(f"[red]Error: Input file '{input_file}' not found.[/red]")
             return
 
-        msgpack_formats = ["atm"]
-        traj_msgpack_formats = ["atraj"]
+        traj_msgpack_formats = ["atraj", "tess"]
         
-        if input_ext not in RW_FORMATS and input_ext not in msgpack_formats and input_ext not in traj_msgpack_formats:
-            console.print(f"[red]Error: Format '{input_ext}' is not supported for reading.[/red]")
+        def _is_supported(ext: str) -> bool:
+            return (
+                ext in RW_FORMATS
+                or ext in traj_msgpack_formats
+            )
+        
+        def _print_supported_error(ext: str, action: str) -> None:
+            console.print(f"[red]Error: Format '{ext}' is not supported for {action}.[/red]")
             console.print("[yellow]Supported read/write formats include:[/yellow]")
             for i in range(0, len(RW_FORMATS), 5):
                 console.print("[yellow]  " + ", ".join(RW_FORMATS[i:i+5]) + "[/yellow]")
-            console.print("[yellow]Special formats: atm (msgpack), atraj (msgpack trajectory)[/yellow]")
+            console.print("[yellow]Special formats: atm (msgpack), atraj (msgpack trajectory), tess (msgpack trajectory)[/yellow]")
+        
+        if not _is_supported(input_ext):
+            _print_supported_error(input_ext, "reading")
             return
-            
-        if output_ext not in RW_FORMATS and output_ext not in msgpack_formats and output_ext not in traj_msgpack_formats:
-            console.print(f"[red]Error: Format '{output_ext}' is not supported for writing.[/red]")
-            console.print("[yellow]Supported read/write formats include:[/yellow]")
-            for i in range(0, len(RW_FORMATS), 5):
-                console.print("[yellow]  " + ", ".join(RW_FORMATS[i:i+5]) + "[/yellow]")
-            console.print("[yellow]Special formats: atm (msgpack), atraj (msgpack trajectory)[/yellow]")
+        
+        if not _is_supported(output_ext):
+            _print_supported_error(output_ext, "writing")
             return
 
         try:
-            if input_ext in msgpack_formats:
-                atoms = load_msgpack(input_file, strict_map_key=strict_map_keys)
-            elif input_ext in traj_msgpack_formats:
-                atoms, _ = load_msgpack_trajectory(input_file, strict_map_key=strict_map_keys)
+            if input_ext == "atraj":
+                atoms, _ = read_atraj(input_file)
+            elif input_ext == "tess":
+                atoms, _ = read_tess(input_file)
             else:
                 atoms = read(input_file, index=":")
         except UnknownFileTypeError:
@@ -140,15 +142,14 @@ def convert(input_file, output_file, strict_map_keys):
             return
         
         try:
-            if output_ext in msgpack_formats:
-                save_msgpack(atoms, output_file)
-                console.print(f"[green]Successfully converted {input_file} to {output_file} (MSGPACK format)[/green]")
-            elif output_ext in traj_msgpack_formats:
-                save_msgpack_trajectory(atoms, output_file)
-                console.print(f"[green]Successfully converted {input_file} to {output_file} (MSGPACK trajectory format)[/green]")
+            if output_ext == "atraj":
+                write_atraj(atoms, output_file)
+            elif output_ext == "tess":
+                write_tess(atoms, output_file)
             else:
                 write(output_file, atoms)
-                console.print(f"[green]Successfully converted {input_file} to {output_file}[/green]")
+
+            console.print(f"[green]Successfully converted {input_file} to {output_file}[/green]")
 
         except UnknownFileTypeError:
             console.print(f"[red]Error: Unknown file type for output file '{output_file}'[/red]")
@@ -199,7 +200,7 @@ if type -q tess
 end
 """
     click.echo(f"# Shell completion for {shell}")
-    click.echo(completion_script.strip())
+    click.echo((completion_script or "").strip())
     click.echo(
         "# Don't forget to source your rc file! `source ~/.bashrc` or `source ~/.zshrc` ..."
     )
